@@ -8,8 +8,6 @@
 ;;;;  Programer:      Kevin Rosenberg based on code by Peter Norvig
 ;;;;  Date Started:   1 Nov 2001
 ;;;;
-;;;; $Id$
-;;;;
 ;;;; This file is Copyright (c) 2001-2002 by Kevin M. Rosenberg
 ;;;; and Copyright (c) 1998-2002 Peter Norvig
 ;;;;
@@ -48,7 +46,7 @@
 
 (defun make-moves ()
   (make-array 60 :element-type 'cons :fill-pointer 0
-              :adjustable nil))
+              :adjustable nil :initial-element (cons nil nil)))
 (deftype moves () '(array cons (60)))
 
 
@@ -83,7 +81,7 @@
    (max-minutes :type fixnum :initarg :max-minutes
                 :documentation "Maximum minites for each player"
                 :reader max-minutes)
-   (clock :type clock :initarg :clock :initform nil
+   (clock :type clock :initarg :clock
           :documentation "An array of time-units left"
           :accessor clock))
   (:default-initargs
@@ -462,4 +460,3 @@
       (dotimes (j N)
         (format t "~4f " (if (eql i j) '---
                            (aref scores i j)))))))
-
